@@ -27,3 +27,17 @@ def img2fft(img: Union[torch.Tensor, np.ndarray]):
         return img2fft_np(img)
     else:
         raise ValueError('unsupported data type ' + str(type(img)))
+
+
+def save_image(img, save_path):
+    # TODO: remove torchvision dependency
+    from torchvision.utils import save_image
+
+    def convert(img):
+        if isinstance(img, list):
+            return [convert(x) for x in img]
+        if isinstance(img, np.ndarray):
+            return torch.from_numpy(img).permute(2, 0, 1)
+        return img
+    
+    save_image(convert(img), save_path, normalize=True)
