@@ -1,3 +1,4 @@
 from .degrade import GaussianBlur, UniformBlur, KFoldDownsample, UniformDownsample, GaussianDownsample, HSI2RGB, Resize, Upsample
-from .noise import GaussianNoise, GaussianNoiseBlind, GaussianNoiseBlindv2, ImpulseNoise, StripeNoise, DeadlineNoise, MixedNoise
-from .general import Compose, MinMaxNormalize, CenterCrop, RandCrop
\ No newline at end of file
+from .noise import GaussianNoise, GaussianNoiseBlind, GaussianNoiseRandom, ImpulseNoise, StripeNoise, DeadlineNoise, MixedNoise
+from .general import Compose, MinMaxNormalize, CenterCrop, RandCrop
+from . import functional
\ No newline at end of file
